("abbreviation" "okrajava")
("about menu" "o programu")
("about" "o programu")
("above" "nad")
("abstract" "povzetek")
("accent" "akcent")
("accept all scripts" "sprejmi vse skripte")
("accept no scripts" "zavrni vse skripte")
("accept script" "sprejmi skript")
("accept" "sprejmi")
("acknowledgment" "potrditev")
("acronym" "akronim")
("action" "akcija")
("activate" "aktiviraj")
("acute" "ostrivec")
("add package" "dodaj paket")
("address block" "blok z naslovom")
("address" "naslov (potni)")
("add switch after" "vstavi stikalo za")
("add switch before" "vstavi stikalo pred")
("advanced layout features" "napredna postavitev")
("advanced" "napredno")
("after" "po")
("albanian" "albansko")
("algorithm" "algoritem")
("align cell to the bottom" "poravnaj celico na dno")
("align cell to the left" "poravnaj celico na levo")
("align cell to the right" "poravnaj celico na desno")
("align cell to the top" "poravnaj celico na vrh")
("aligned" "poravnano")
("aligned" "poravnano")
("aligned" "poravnano")
("alignment" "poravnava")
("align table at base of left column" "poravnaj tabelo na bazo levega stolpca")
("align table at base of middle column" "poravnaj tabelo na bazo srednjega stolpca")
("align table at base of origin column" "poravnaj tabelo na bazo izvornega stolpca")
("align table at base of right column" "poravnaj tabelo na bazo desnega stolpca")
("align table at fraction bar height" "poravnaj tabelo na viino ulomka")
("align table at the base of bottom row" "poravnaj tabelo na bazo spodnje vrstice")
("align table at the base of middle row" "poravnaj tabelo na bazo srednje vrstice")
("align table at the base of origin row" "poravnaj tabelo na bazo izvorne vrstice")
("align table at the base of top row" "poravnaj tabelo na bazo zgornje vrstice")
("align table at the bottom" "poravnaj tabelo na dno")
("align table at the center" "poravnaj tabelo na sredino")
("align table at the horizontal center" "poravnaj tabelo na vodoravno sredino")
("align table at the left" "poravnaj tabelo na levo")
("align table at the top" "poravnaj tabelo na vrh")
("align table to the right" "poravnaj tabelo na desno")
("align text to the left" "poravnaj besedilo na levo")
("align text to the right" "poravnaj besedilo na desno")
("allow" "dovoljeno")
("allowed extension" "dovoljena raziritev")
("allowed reduction" "dovoljena skritev")
("all" "vse")
("alpha release" "alfa verzija")
("alternative specification" "alternativna specifikacija")
("alt key" "tipka alt")
("american" "ameriko")
("a modifier" "modifikator A")
("a modifier" "modifikator A")
("A modifier" "modifikator A")
("and" "in")
("appendix" "dodatek")
("apply" "apliciraj")
("april" "april")
("arab" "arabsko")
("archaic" "arhaino")
("architecture" "arhitektura")
("argument" "argument")
("arithmetic" "aritmetika")
("armenian" "armensko")
("arrow" "puica")
("arrows" "puice")
("article" "lanek")
("as on paper" "kot na papirju")
("assign" "priredi")
("at fraction bar height" "na ulomkovo rto")
("attach buffer to which project" "pripni spis na projekt")
("attach" "pripni")
("at the baseline" "na osnovnico")
("at the bottom" "spodaj")
("at the left" "levo")
("at the middle" "sredina")
("at the right" "desno")
("at the top" "na vrh")
("august" "avgust")
("author" "avtor")
("authorize" "avtoriziraj")
("automatically close brackets" "avtomatsko zapiranje oklepajev")
("automatically close brackets" "samodejno zapiraj oklepaje")
("automatically generated content" "avtomatsko generirana vsebina")
("automatic" "avtomatsko")
("autosave" "samodejno shranjevanje")
("autosave" "samoshranjevanje")
("axiom" "aksiom")
("background color" "barva ozadja")
("background evaluations" "vrednotenje v ozadju")
("background evaluations" "vrednotenje v ozadju")
("background" "ozadje")
("backward replace" "zamenjaj proti zaetku")
("backward search" "ii proti zaetku")
("bad data format" "slab zapis datuma")
("bard" "bard")
("bar" "rta")
("base level" "osnovni nivo")
("bashkirian" "bashkirian")
("basic communication using pipes" "osnovna komunikacija preko cevi")
("basic communication using pipes" "osnovna komunikacija preko cevovodov")
("basic data types" "osnovni podatkovni tipi")
("basic" "osnovni")
("basic types" "osnovni tipi")
("become a TeXmacs developer" "postanite TeXmacs razvijalec")
("before" "pred")
("begin" "zaetek")
("below" "pod")
("beta release" "beta release")
("be useful" "bodi uporaben")
("bibliography file" "datoteka z literaturo")
("bibliography" "literatura")
("bibliography style" "slog literature")
("big figure" "velika slika")
("big operator" "velik operator")
("big skip" "velik preskok")
("big table" "velika tabela")
("big" "veliko")
("binary operation" "dvojika operacija")
("binary relation" "dvojika relacija")
("blackboard bold" "blackboard krepko")
("blackboard math" "blackboard matematika")
("blackletter" "blackletter")
("black" "rna")
("blue" "modra")
("body" "telo")
("bold" "krepko")
("book" "knjiga")
("border" "obroba")
("both" "oba")
("bottom border" "spodnja obroba")
("bottom" "dno")
("bottom margin" "spodnji rob")
("bottom padding" "spodnja obloga")
("branch" "vejitev")
("breaking" "prelamljanje")
("break" "prelom")
("breve" "breve")
("british" "britansko")
("brown" "rjava")
("browse" "prebrskaj")
("browser" "brskalnik")
("browse web" "prebrskaj splet")
("buffer" "spis")
("bulgarian" "bolgarsko")
("bullet" "pika")
("bullets" "pike")
("by" "avtor:")
("bytes free" "prostih bajtov")
("bytes used" "uporabljenih bajtov")
("by typing" "s tipkanjem")
("calligraphic" "kaligrafsko")
("cancel" "preklii")
("caps-lock key" "tipka caps-lock")
("case" "case")
("cc" "kopija")
("cell background color" "barva ozadja v celici")
("cell border" "obroba celice")
("cell" "celica")
("cell height" "viina celice")
("cell operation mode" "reim celice")
("cell width" "irina celice")
("centered block" "centriran blok")
("centered" "na sredini")
("centered tabular" "centriran tabular")
("center" "sredina")
("center text" "poravnaj besedilo na sredino")
("change border of cell" "spremeni obrobo celice")
("change cell operation mode" "spremeni reim celice")
("change log" "dnevnik sprememb")
("changes" "spremembe")
("chapter" "poglavje")
("check" "streica")
("check text for spelling errors" "preii besedilo za pravopisne napake")
("chinese" "kitajsko")
("choice" "izbira")
("citation" "sklic na literaturo")
("cite" "citat")
("class" "razred")
("clear" "izbrii")
("clear selection" "izbrii izbiro")
("clipped and magnified" "obrezano in poveava")
("clipped and resized" "obrezano in poveano")
("clipped" "obrezano")
("clone" "podvoji")
("clone window" "podvoji okno")
("close buffer" "zapri spis")
("close session" "zapri sejo")
("close TeXmacs" "zapri TeXmacs")
("close window" "zapri okno")
("close" "zapri")
("closing style" "slog zapiranja")
("closing" "zapiram")
("code" "koda")
("color" "barva")
("column contains glued items" "stolpec vsebuje lepilo")
("column" "stolpec")
("compactification" "kompaktifikacija")
("compact" "kompaktno")
("compact" "kompaktno")
("compact" "kompaktno")
("compatibility with other formats" "zdruljivost z drugimi zapisi")
("compile article" "prevedi lanek")
("compile book" "prevedi knjigo")
("compile buffer" "prevedi spis")
("compile project" "prevedi projekt")
("completion" "dopolnitev")
("completion" "dopolnitev")
("complex" "kompleksno")
("concrete" "concrete")
("condensed" "zoeno")
("condition" "condition")
("condition" "pogoj")
("configuration" "konfiguracija")
("contact" "kontakt")
("contact" "kontakt")
("content tag" "vsebinska oznaka")
("content" "vsebina")
("content" "vsebina")
("content" "vsebina")
("context dependent icons" "kontekstno odvisne ikone")
("continuation of" "nadaljevanje od")
("contribute" "prispevajte")
("contribute" "prispevajte")
("convention" "konvencija")
("converters to other data formats" "pretvorniki v druge zapise podatkov")
("copying" "kopiram")
("copy" "kopiraj")
("copy text" "kopiraj besedilo")
("copy to" "kopiraj v")
("corollary" "korolar")
("correct text" "popravi besedilo")
("create web site" "ustvari spletno mesto")
("cursors" "kurzorji")
("customize" "prilagodi")
("customizing TeXmacs" "prilagajanje TeXmacsa")
("customizing the TeXmacs styles" "prilagajanje TeXmacs slogov")
("custom tab" "poseben tabulator")
("custum tab" "poseben tabulator")
("cut" "izrei")
("cut text" "izrei besedilo")
("cut to" "izrei v")
("cypriot" "cypriot")
("cyrillic" "cirilica")
("cyrillic input method" "vhodna metoda za cirilico")
("cyrillic italic right" "cirilica kurzivno desno")
("czech" "eko")
("dancers" "dancers")
("danish" "dansko")
("dark grey" "temno siva")
("dark grey" "temno siva")
("dashes" "rtice")
("dash" "rtica")
("data conversion" "pretvorba podatkov")
("data format" "oblikovanje podatkov")
("date" "datum")
("deactivate" "deaktiviraj")
("deactivate table" "deaktiviraj tabelo")
("december" "december")
("decorate atoms" "okrasi atome")
("default padding" "privzeta obloga")
("default" "privzeto")
("definition" "definicija")
("delete column" "izbrii stolpec")
("delete" "izbrii")
("delete row" "izbrii vrstico")
("denominator" "imenovalec")
("description" "opis")
("destination" "cilj")
("detach" "loi")
("detailed" "podrobno")
("determinant" "determinanta")
("devangari" "devangari")
("developers guide" "vodi za razvijalce")
("directory" "imenik")
("disable first indentation after" "onemogoi prvi zamik za")
("disable first indentation before" "onemogoi prvi zamik pred")
("disable first indentation" "onemogoi prvi zamik")
("disable indentation after" "onemogoi zamik za")
("disable indentation before" "onemogoi zamik pred")
("disable indentation" "onemogoi zamik")
("disable last indentation after" "onemogoi zadnji zamik za")
("disable last indentation before" "onemogoi zadnji zamik pred")
("disable last indentation" "onemogoi zadnji zamik")
("disable" "onemogoi")
("disable" "onemogoi")
("disallow" "prepovej")
("distribute unused space" "porazdeli neporabljen prostor")
("div" "razdelek")
("documentation" "dokumentacija")
("document" "dokument")
("document format" "format dokumenta")
("documents are trees" "dokumenti so drevesa")
("document style" "slog dokumenta")
("document styles" "slogi dokumenta")
("do not remap" "ne mapiraj")
("do not remap" "ne remapiraj")
("dots" "toke")
("dot" "toka")
("double stroke" "dvakrat prertano")
("down" "dol")
("dpi" "DPI")
("duplicate" "podvoji")
("dutch" "holandsko")
("dynamic libraries" "dinamine knjinice")
("editing tools" "orodja za urejanje")
("edit source tree" "urejaj izvorno kodo")
("edit" "urejanje")
("email" "email")
("emphasize" "poudarjeno")
("emphasize text" "poudari besedilo")
("empty box" "prazna katla")
("enable first indentation after" "omogoi prvi zamik za")
("enable first indentation before" "omogoi prvi zamik pred")
("enable first indentation" "omogoi prvi zamik")
("enable indentation after" "omogoi zamik za")
("enable indentation before" "omogoi zamik pred")
("enable indentation" "omogoi zamik")
("enable last indentation after" "omogoi zadnji zamik za")
("enable last indentation before" "omogoi zadnji zamik pred")
("enable last indentation" "omogoi zadnji zamik")
("encl" "encl")
("end" "konec")
("english" "angleina")
("enter a title" "vpii naslov")
("enumerate|alpha" "tevili|abecedno")
("enumerate|Alpha" "tevili|Abecedno")
("enumerate|roman" "tevili|rimsko")
("enumerate|Roman" "tevili|Rimsko")
("enumerate" "tevili")
("env" "env")
("environment" "okolje")
("epilogue" "epilog")
("equal" "enako")
("equation" "enaba")
("equations" "enabe")
("equivalent for" "ekvivalent za")
("error" "napaka")
("esperanto" "esperanto")
("etruscan" "etruansko")
("evaluate" "ovrednoti")
("evaluate scheme expression" "ovrednoti izraz v Scheme")
("evaluation" "ovrednotenje")
("even page footer" "noga sodih strani")
("even page header" "glava sodih strani")
("even page left margin" "levi rob sodih strani")
("even page margin" "rob sodih strani")
("even page right margin" "desni rob sodih strani")
("even page text" "besedilo sodih strani")
("exact horizontal" "tono vodoravno")
("exact mode" "toen reim")
("exam" "izpit")
("example" "primer")
("exclusive" "ekskluzivno")
("exclusive or" "ekskluzivni ali")
("executable" "izvrna koda")
("execute a TeXmacs command" "izvri ukaz TeXmacsa")
("execute" "izvri")
("execute system command" "izvri ukaz sistema")
("executive" "executive")
("exercise" "vaja")
("expand" "raziri")
("explained" "razloeno")
("export as" "izvozi kot")
("export" "izvozi")
("extend or normal" "razirjeno ali normalno")
("extern " "zunanje")
("extern" "zunanji")
("extract format" "toen format")
("extra" "ekstra")
("family" "druina")
("february" "februar")
("figure" "slika")
("file" "datoteka")
("file already exists" "datoteka e obstaja")
("file name" "ime datoteke")
("file not found" "ne najdem datoteke")
("find file" "najdi datoteko")
("find next match" "poii naslednjega")
("find text" "poii besedilo")
("finnish" "Finsko")
("first contact" "prvi kontakt")
("first indentation" "prvi zamik")
("first item" "prva postavka")
("first page" "prva stran")
("first start" "zaetek od")
("flat" "sploeno")
("flexibility factor for vertical spacing" "faktor raztegljivosti za navpine razmike")
("flexibility" "fleksibilnost")
("floating figure" "plavajoa slika")
("floating object" "plavajo objekt")
("floating table" "plavajoa tabela")
("flow control" "kontrola toka")
("folded" "prepognjeno")
("fold input field" "prepogni vnosno polje")
("fold" "prepogni")
("font base size" "osnovna velikost pisave")
("font dpi" "DPI pisave")
("font family" "druina pisave")
("font name" "ime pisave")
("font" "pisava")
("font series" "serija pisave")
("font shape" "oblika pisave")
("font size" "velikost pisave")
("fonts" "pisave")
("font type" "vrsta pisave")
("font variant" "varianta pisave")
("footer" "noga")
("footnote" "opomba pod rto")
("foreground" "ospredje")
("foreign" "tuje")
("for" "for")
("format" "oblika")
("formatted date" "formatiran datum")
("formatting" "formatiranje")
("formula" "formula")
("formula style" "slog formule")
("forward replace" "zamenjaj naprej")
("forward search" "ii naprej")
("fraction" "ulomek")
("french" "francosko")
("full manuals" "celotni prironiki")
("full screen mode" "celozaslonski reim")
("function" "funkcija")
("further customization" "nadaljne prilagajanje")
("future changes" "prihodnje spremembe")
("general architecture of TeXmacs" "oba architektura TeXmacsa")
("general negation" "oba negacija")
("general note" "splona opomba")
("generating font file" "raunam pisavo")
("generic" "obe")
("georgian" "georgian")
("german" "nemko")
("getting started" "kako zaeti")
("glossary" "besednjak")
("glossary entry" "zapis v besednjaku")
("glue decorations" "prilepi dekoracijo")
("glue" "lepilo")
("GNU" "GNU")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs je brez kakrnegakoli pravnega jamstva")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs spada pod javno licenco GNU")
("go" "pojdi na")
("gothic" "gotica")
("graphical interface" "grafini vmesnik")
("grave" "krativec")
("greater or equal" "veje ali enako")
("greater" "veje")
("greek" "grko")
("greek letter" "grka rka")
("green" "zelena")
("grey" "siva")
("group" "skupina")
("happy typing" "sreno tipkanje")
("has been aborted" "je bil prekinjen")
("has completed its task" "je konal nalogo")
("hat" "streica")
("header and footer" "glava in noga")
("header" "glava")
("hebrew" "hebrejsko")
("height is exactly the specified height" "viina je natanko doloena viina")
("height is maximum of specified height and box height" "viina je maksimum doloene viine in viine katle")
("height is minimum of specified height and box height" "viina je minimum doloene viine in viine katle")
("height magnification" "poveava viine")
("height" "viina")
("help me" "pomagajte mi")
("help" "pomo")
("help us" "pomagajte nam")
("here" "tukaj")
("h modifier" "modifikator H")
("h modifier" "modifikator H")
("H modifier" "modifikator H")
("hidden" "skrito")
("home" "domov")
("homepage" "domaa stran")
("horizontal cell alignment" "vodoravna poravnava celice")
("horizontal ink separation" "vodoravni razmik med rnili")
("horizontally align cell to the base" "vodoravno poravnaj celico na bazo")
("horizontally center the cell" "vodoravno centriraj celico")
("horizontal part" "vodorovni del")
("horizontal position" "vodorovna pozicija")
("horizontal space" "vodoravni presledek")
("horizontal table alignment" "vodorovna poravnava tabele")
("horizontal" "vodoravno")
("how much longer may pages become" "koliko se lahko stran podalja")
("how much shorter may pages become" "koliko se lahko stran skraja")
("html" "HTML")
("huge" "ogromno")
("hungarian" "madarsko")
("hybrid command" "hibriden ukaz")
("hybrid command" "hibriden ukaz")
("hyperlink" "hiperpovezava")
("hyphenation" "deljenje besed")
("icelandic" "islandsko")
("if" "if")
("image links" "povezave na sliko")
("image" "slika")
("implementation" "implementacija")
("import" "uvozi")
("improving the current implementation" "izboljava trenutne izvedbe")
("inactive" "neaktivno")
("include a document" "vstavi dokument")
("include file" "vstavi datoteko")
("include" "vkljui")
("inclusion into TeXmacs" "vkljuitev v TeXmacs")
("inclusions" "vloki")
("indentation flag" "nastavitev zamika")
("indent" "zamik")
("index entry" "zapis v stvarnem kazalu")
("index level" "nivo stvarnega kazala")
("index" "stvarno kazalo")
("informative flags" "informativne oznake")
("input mode" "vhodni reim")
("insert a big operator" "vstavi veliki operator")
("insert a binary operation" "vstavi dvojiko operacijo")
("insert a binary relation" "vstavi dvojiko relacijo")
("insert a blackboard bold character" "vstavi blackboard bold znak")
("insert a bold calligraphic character" "vstavi krepki kaligrafski znak")
("insert a bold character" "vstavi krepki znak")
("insert a calligraphic character" "vstavi kaligrafski znak")
("insert a fraction" "vstavi ulomek")
("insert a fraktur character" "vstavi fraktur znak")
("insert a greek character" "vstavi grko rko")
("insert a large left delimiter" "vstavi veliki levi loevalnik")
("insert a large right delimiter" "vstavi veliki desni loevalnik")
("insert a large separator" "vstavi veliki razdelilnik")
("insert a left subscript" "vstavi levi indeks")
("insert a link" "vstavi povezavo")
("insert a miscellaneous symbol" "vstavi drug simbol")
("insert an accent" "vstavi akcent")
("insert an arrow" "vstavi puico")
("insert an environment" "vstavi okolje")
("insert a new branch" "vstavi novo vejitev")
("insert a new item" "vstavi novo alinejo")
("insert an n" "vstavi n")
("insert an" "vstavi")
("insert a picture" "vstavi sliko")
("insert appendix" "vstavi dodatek")
("insert arccos" "vstavi arccos")
("insert arcsin" "vstavi arcsin")
("insert arctan" "vstavi arctan")
("insert argument" "vstavi argument")
("insert arg" "vstavi arg")
("insert a square root" "vstavi kvadratni koren")
("insert a table or a matrix" "vstavi tabelo ali matriko")
("insert a table" "vstavi tabelo")
("insert a TeXmacs symbol" "vstavi TeXmacs simbol")
("insert automatically generated content" "vstavi automatsko generirano vsebino")
("insert author" "vstavi avtorja")
("insert a wide symbol above" "vstavi irok simbol nad")
("insert a wide symbol below" "vstavi irok simbol pod")
("insert big contour integral" "vstavi veliki krivuljni integral")
("insert big coproduct" "vstavi veliki koprodukt")
("insert big direct sum" "vstavi veliko direktno vsoto")
("insert big dotted point" "vstavi veliko piko s kolesom")
("insert big integral" "vstavi veliki integral")
("insert big intersection" "vstavi veliki presek")
("insert big logical and" "vstavi veliko konjunkvijo")
("insert big logical or" "vstavi veliko disjunkcijo")
("insert big product" "vstavi veliki produkt")
("insert big square union" "vstavi veliko oglato unijo")
("insert big summation" "vstavi veliko vsoto")
("insert big tensor product" "vstavi veliki tenzorski produkt")
("insert big union sum" "vstavi veliko vsoto unij")
("insert big union" "vstavi veliko unijo")
("insert big vertical space" "vstavi veliki navpini presledek")
("insert chapter" "vstavi poglavje")
("insert column to the left" "vstavi stolpec na levi")
("insert column to the right" "vstavi stolpec na desni")
("insert column" "vstavi stolpec")
("insert cosh" "vstavi cosh")
("insert cos" "vstavi cos")
("insert coth" "vstavi coth")
("insert cot" "vstavi cot")
("insert csc" "vstavi csc")
("insert deg" "vstavi deg")
("insert det" "vstavi det")
("insert dim" "vstavi dim")
("insert dollar" "vstavi dolar")
("insert equation" "vstavi enabo")
("insert executable markup" "vstavi izvrljive znake")
("insert exp" "vstavi exp")
("insert fields" "vstavi polja")
("insert footnote" "vstavi opombo pod rto")
("insert formula" "vstavi vzorec")
("insert gcd" "vstavi gcd")
("insert hom" "vstavi hom")
("insert horizontal interword space" "vstavi vodoravni medbesedni presledek")
("insert image" "vstavi sliko")
("insert inactive markup" "vstavi neaktivno znako")
("insert inf" "vstavi inf")
("insert input field above" "vstavi vnosno polje nad")
("insert input field below" "vstavi vnosno polje pod")
("insert ker" "vstavi ker")
("insert lg" "vstavi lg")
("insert liminf" "vstavi liminf")
("insert limsup" "vstavi limsup")
("insert lim" "vstavi lim")
("insert ln" "vstavi ln")
("insert log" "vstavi log")
("insert macro" "vstavi makro")
("insert mathematics" "vstavi matematiko")
("insert max" "vstavi max")
("insert medium horizontal space" "vstavi srednji vodoravni presledek")
("insert medium vertical space" "vstavi srednji navpini presledek")
("insert min" "vstavi min")
("insert negative horizontal space" "vstavi negativni vodorovni presledek")
("insert new item or number" "vstavi novo alinejo")
("insert new rows or columns" "vstavi nove stolpce ali vrstice")
("insert or delete rows or columns" "vstavi ali izbrii stolpce ali vrstice")
("insert Pr" "vstavi Pr")
("insert row above" "vstavi vrstico nad")
("insert row below" "vstavi vrstico pod")
("insert row" "vstavi vrstico")
("insert section" "vstavi razdelek")
("insert sec" "vstavi sec")
("insert sharp" "vstavi viaj")
("insert sinh" "vstavi sinh")
("insert sin" "vstavi sin")
("insert small horizontal space" "vstavi mali vodorovni presledek")
("insert small vertical space" "vstavi mali navpini presledek")
("insert structural markup" "vstavi strukturne znake")
("insert subsection" "vstavi podrazdelek")
("insert subsubsection" "vstavi podpodrazdelek")
("insert sup" "vstavi sup")
("insert tanh" "vstavi tanh")
("insert tan" "vstavi tan")
("insert text field" "vstavi tekstovno polje")
("insert thick horizontal space" "vstavi debel vodoraven presledek")
("insert title" "vstavi naslov")
("insert value" "vstavi vrednost")
("insert" "vstavi")
("interfacing" "povezovanje")
("interfacing TeXmacs with other systems" "povezava TeXmacsa z drugimi sistemi")
("interjection" "interjection")
("interline separation" "loitev med vrsticami")
("interline space" "presledek med vrsticami")
("internationalization" "lokalizacija")
("interparagraph space" "presledek med odstavki")
("interrupt execution" "prekini izvajanje")
("introduction" "uvod")
("invisible citation" "neviden citat")
("invisible" "nevidno")
("irish" "irsko")
("ispell does not respond" "ispell se ne odziva")
("ispell is already busy" "ispell je zaposlen")
("is running" "tee")
("is tuple" "je n-terka")
("italian" "italijansko")
("italic" "kurzivno")
("italic right" "kurzivno desno")
("item" "alineja")
("itemize" "alineje")
("january" "januar")
("japanese" "japonsko")
("july" "julij")
("june" "junij")
("justified" "obojestranska")
("justify text" "poravnaj besedilo obojestransko")
("keyboard equivalent" "ekvivalent na tipkovnici")
("keyboard modifiers" "modifikator tipkovnice")
("keyboard shortcut" "okrajava na tipkovnici")
("keyboard" "tipkovnica")
("keymaps" "razporeditve tipk")
("key" "tipka")
("keyword" "kljuna beseda")
("keywords" "kljune besede")
("kill" "pobij")
("known bugs" "znani hroi")
("label" "oznaka")
("landscape" "pokrajina")
("language" "jezik")
("large closing bracket" "veliki zaklepaj")
("large delimiter" "veliki loevalnik")
("large opening bracket" "veliki predklepaj")
("large separator" "veliki razdelilnik")
("large" "veliko")
("last indentation" "zadnji zamik")
("last page" "zadnja stran")
("latex command" "LaTeX ukaz")
("LaTeX" "LaTeX")
("latin" "latinica")
("layout" "postavitev")
("left arrow" "puica levo")
("left arrow" "puica levo")
("left border" "leva obroba")
("left" "levo")
("left margin" "levi rob")
("left padding" "leva obloga")
("left prime" "left prime")
("left ragged" "leva")
("left slanted" "postrani levo")
("left subscript" "levi indeks")
("left superscript" "levi eksponent")
("left surrounding" "levo naokoli")
("legal" "legal")
("lemma" "lema")
("length" "dolina")
("less" "manje")
("less or equal" "manje ali enako")
("letter" "pismo")
("license" "licenca")
("light grey" "svetlo siva")
("light grey" "svetlo siva")
("light" "lahko")
("limitations" "omejitve")
("limits" "omejitev")
("line break" "prelom vrste")
("line stretch" "razteg vrstice")
("line" "vrstica")
("link image" "povei sliko")
("link" "povezava")
("list of figures" "seznam slik")
("list of tables" "seznam tabel")
("list" "seznam")
("load a file" "naloi datoteko")
("load buffer" "naloi spis")
("loaded" "naloeno")
("load file" "naloi datoteko")
("load html file" "naloi datoteko HTML")
("load image" "naloi sliko")
("load in new window" "naloi v novo okno")
("load latex file" "naloi datoteko LaTeX")
("load LaTeX file" "naloi datoteko LaTeX")
("load more recent autosave file" "naloi novejo avtomatsko shranjeno datoteko")
("load" "naloi")
("load tex file" "naloi datoteko TeX")
("load TeX file" "naloi datoteko TeX")
("load TeXmacs file" "naloi datoteko TeXmacs")
("load TeXmacs style file" "naloi datoteko TeXmacs slog")
("load verbatim file" "odpri datoteko dobesedno")
("long" "dolgo")
("look and feel" "obutek in videz")
("look up" "poglej v")
("lower border" "nija obroba")
("macro" "makro")
("magenta" "magenta")
("magic" "arovnija")
("magnification" "poveava")
("magnified" "poveano")
("main" "glavni")
("main icon bar" "glavne ikone")
("major changes" "glavne spremembe")
("make acute" "ustvari ostrivec")
("make a page insertion" "vstavi v stran")
("make a subscript" "ustvari indeks")
("make a superscript" "ustvari eksponent")
("make bar" "make bar")
("make check" "vstavi streico")
("make fraction" "ustvari ulomek")
("make grave" "ustvari krativec")
("make hat" "make hat")
("make label" "ustvari oznako")
("make negation" "ustvari negacijo")
("make page reference" "ustvari sklic na stran")
("make reference" "ustvari sklic")
("make square root" "ustvari kvadratni koren")
("make tilde" "ustvari tildo")
("make title" "ustvari naslov")
("make vector" "ustvari vektor")
("making donations" "finanna podpora")
("manual" "prironik")
("map to" "mapiraj na")
("march" "marec")
("margins as on paper" "robovi kot na papirju")
("margins" "robovi")
("master file" "datoteka gospodar")
("master" "gospodar")
("mathematical font" "pisava za matematiko")
("mathematical formulas" "matematine formule")
("mathematical input" "matematien vnos")
("mathematical input" "matematien vnos")
("mathematical" "matematino")
("mathematical typesetting" "matematino stavljenje")
("mathematics" "matematika")
("math font family" "druina matematine pisave")
("math font" "pisava za matematiko")
("math font series" "serija matematine pisave")
("math font shape" "oblika matematine pisave")
("math" "matematika")
("matrix" "matrika")
("maximal" "maksimalno")
("maximal number of columns" "najve stolpcev")
("maximal number of rows" "najve vrstic")
("maximum mode" "maksimalni reim")
("may" "maj")
("medium skip" "srednji preskok")
("medium" "srednje")
("meminfo" "informacije o pomnilniku")
("memory information" "informacije o pomnilniku")
("merge" "zdrui")
("messy" "messy")
("meta key" "tipka meta")
("middle" "sredina")
("minimal" "minimalno")
("minimal number of columns" "najmanj stolpcev")
("minimal number of rows" "najmanj vrstic")
("minimum mode" "minimalni reim")
("minus" "minus")
("miscellaneous" "razno")
("m modifier" "modifikator M")
("m modifier" "modifikator M")
("M modifier" "modifikator M")
("mode" "nain")
("modifier" "modifikator")
("modify cell alignment" "spremeni poravnavo celice")
("modify cell border" "spremeni obrobo celice")
("modify cell padding" "spremeni oblogo celice")
("modify cell size" "spremeni velikost celice")
("modify table border" "spremeni obrobo tabele")
("modify table padding" "spremeni oblogo tabele")
("mod" "modulo")
("mongolian" "mongolsko")
("more information about GNU TeXmacs can be found in the help" "Ve informacij o GNU TeXmacsu lahko najdete v pomoi")
("mosaic" "mozaik")
("move down" "premakni dol")
("move object" "premakni objekt")
("move to the right when finished" "prestavi desno ko kona")
("move up" "premakni gor")
("multiline input" "vevrstini vnos")
("multiline input" "vnos v ve vrsticah")
("my documents" "moji dokumenti")
("my documents" "moji dokumenti")
("name" "ime")
("negation" "negacija")
("new buffer" "nov spis")
("new column" "nov stolpec")
("new item" "nova alineja")
("new line" "nova vrsta")
("new" "nova")
("new number" "novo tevilo")
("new page before" "nova stran pred")
("new page" "nova stran")
("new paragraph" "nov odstavek")
("new roman" "new roman")
("new row" "nova vrstica")
("new table" "nova tabela")
("next line" "naslednja vrstica")
("next" "naslednje")
("next" "naslednji")
("no changes need to be saved" "shranjevanje sprememb ni potrebno")
("no dictionary for" "ni slovarja za")
("no first indentation" "brez prvega zamika")
("no indentation" "brez zamika")
("no last indentation" "brez poslednjega zamika")
("no line break" "brez preloma vrste")
("no matches found for" "ni ujemanja za")
("no matches found" "ni najdeno")
("no more matches for" "ni ve najdb za")
("no more redo information available" "na koncu")
("no more undo information available" "na zaetku")
("no name" "brez imena")
("none" "brez")
("no page break after" "brez preloma strani za")
("no page break before" "brez preloma strani pred")
("normal" "normalno")
("norwegian" "norveko")
("no spelling errors found in text" "besedilo je brez pravopisnih napak")
("no style" "brez sloga")
("notation" "notacija")
("note" "notica")
("not equal" "neenako")
("not found" "ni najdeno")
("not" "non")
("november" "november")
("n-th" "n-ti")
("n-th root" "n-ti koren")
("numbered equations" "tevilene enabe")
("numbered equation" "tevilena enaba")
("number equation" "otevili enabo")
("number of columns" "tevilo stolpcev")
("number" "tevilo")
("numerator" "tevec")
("numeric" "numerino")
("objectives" "cilj")
("occurrences" "pojavov")
("october" "oktober")
("odd page footer" "noga lihih strani")
("odd page header" "glava lihih strani")
("odd page left margin" "levi rob lihih strani")
("odd page margin" "rob lihih strani")
("odd page text" "besedilo lihih strani")
("off" "izklopljeno")
("ok" "ok")
("old english" "staro angleko")
("old slavonic" "staro slovensko")
("old style" "stari slog")
("on cells" "na celice")
("on columns" "na stolpce")
("on entire table" "na celo tabelo")
("one spelling error has been corrected" "ena pravopisna napaka odpravljena")
("online documentation" "online dokumentacija")
("online help" "online pomo")
("on rows" "na vrstice")
("on" "vklopljeno")
("open a new buffer" "odpri nov spis")
("opening" "odpiram")
("open new window" "odpri novo okno")
("open" "odpri")
("operation on named selection" "operacija na poimenovani izbiri")
("operation on primary selection" "operacija na primarni izbiri")
("operation on secondary selection" "operacija na sekundarni izbiri")
("operation on ternary selection" "operacija na terciarni izbiri")
("optical" "optical")
("option" "nastavitev")
("options" "nastavitve")
("or" "ali")
("orange" "oranna")
("orientation" "orientacija")
("original welcome message" "originalna dobrodolica")
("origin" "pvod")
("other" "drugo")
("other pages" "druge strani")
("other projects" "drugi projekti")
("other style" "drug slog")
("outlined roman" "roman obrobljeno")
("overbrace" "nadklepaj")
("overbrace" "nadklepaj")
("overline" "nadrtano")
("over" "nad")
("overwrite existing file" "naj prepiem obstojeo datoteko (y/n)")
("padding" "obloga")
("page bottom margin" "spodnji rob strani")
("page break before" "prelom strani pred")
("page break" "prelom strani")
("page height" "viina strani")
("page insertion" "vstavi na stran")
("page layout" "postavitev strani")
("page numbering" "tevilenje strani")
("page number text" "tekst tevilke strani")
("page reference" "sklic na stran")
("page right margin" "desni rob strani")
("page setup" "nastavitev strani")
("page" "stran")
("page top margin" "zgornji rob strani")
("page type" "tip strani")
("page width" "irina strani")
("paper" "papir")
("paper type" "velikost papirja")
("papyrus" "papirus")
("paragraph mode" "reim odstavka")
("paragraph" "odstavek")
("paragraph width" "irina odstavka")
("part" "del")
("past changes" "minule spremembe")
("paste from" "prilepi iz")
("paste" "prilepi")
("paste text" "prilepi besedilo")
("path" "pot")
("pdf" "PDF")
("perform operations on cells" "izvedi operacijo na celicah")
("perform operations on columns" "izvedi operacijo na stolpcih")
("perform operations on entire table" "izvedi operacijo na celotni tabeli")
("perform operations on rows" "izvedi operacijo na vrsticah")
("permanent" "permanentno")
("personal dictionary has been modified" "osebni slovar je bil spremenjen")
("person" "oseba")
("phantasy" "fantazija")
("philosophy" "filozofija")
("phoenician" "fenian")
("phonetic" "fonetino")
("pink" "ronata")
("plain block" "navaden blok")
("plain tabular" "navaden tabular")
("planned changes" "nartovane spremebe")
("plans for the future" "narti za prihodnost")
("please" "prosim")
("please wait" "poakajte prosim")
("plugins" "vstavki")
("plugins" "vstavki")
("plugin" "vstavek")
("plugin" "vstavek")
("plus" "plus")
("polish" "poljsko")
("porting TeXmacs to other platforms" "prenos TeXmacsa na druge platforme")
("portrait" "portret")
("portuguese" "portugalsko")
("position floating object" "pozicioniraj plavajo objekt")
("position float" "pozicionioraj plovko")
("position" "pozicija")
("position the table" "pozicioniraj tabelo")
("postscript image" "slika v PostScriptu")
("postscript" "postscript")
("pre-alpha release" "pred-alfa release")
("preamble mode" "reim preambule")
("preamble" "preambula")
("preferences" "nastavitve")
("presentation mode" "prezentacijski reim")
("presentation" "prezentacija")
("presentation tag" "prezentacijska oznaka")
("preview before printing" "predogled tiskanja")
("preview command" "ukaz za predogled")
("preview with ghostview" "predogled z GhostScriptom")
("previous" "prejnje")
("previous" "prejnji")
("primary" "primarno")
("prime" "pratevilo")
("print all" "natisni vse")
("print all to file" "natisni vse v datoteko")
("printer dpi" "DPI tiskalnika")
("printer" "tiskalnik")
("printing command" "ukaz za tiskanje")
("print" "natisni")
("print page selection" "natisni izbor strani")
("print page selection to file" "natisni izbor strani v datoteko")
("print to postscript file" "natisni v PostScript datoteko")
("problem" "problem")
("professional" "profesionalno")
("prog font family" "druina pisave za prog")
("prog font" "pisava za prog")
("prog font series" "serija pisave za prog")
("prog font shape" "oblika pisave za prog")
("prog" "prog")
("program font" "pisava za programe")
("programming" "programiranje")
("program mode" "reim programa")
("program" "program")
("progressive" "progresivno")
("project" "projekt")
("projects" "projekti")
("prologue" "prolog")
("prompt on scripts" "vpraaj pri skriptih")
("proof" "dokaz")
("proportional" "proporcionalno")
("proportional typewriter" "proporcionalni pisalni stroj")
("proposition" "izjava")
("query replace" "zamenjaj s potrditvijo")
("quit" "konec")
("quotation" "quotation")
("quote" "quote")
("range" "obseg")
("really close it" "zares zapri")
("really huge" "zares ogromno")
("really quit" "zares konaj")
("really tiny" "zares drobno")
("recover autosave file" "povrnem samodejno shranjeno datoteko")
("redo" "ponovi")
("redo undone changes" "ponovi razveljavljeno")
("red" "rdea")
("reduce bottom margin by" "zmanjaj spodnji rob za")
("reduce left margin by" "zmanjaj levi rob za")
("reduce margins" "zmanjaj robove")
("reduce right margin by" "zmanjaj desni rob za")
("reduce top margin by" "zmanjaj zgornji rob za")
("reduction even page margin" "pomanjava roba sodih strani")
("reduction odd page margin" "pomanjava roba lihih strani")
("reduction page bottom margin" "pomanjava spodnjega roba strani")
("reduction page right margin" "pomanjava desnega roba strani")
("reduction page top margin" "pomanjava zgornjega roba strani")
("reference" "sklic")
("reference guide" "Referenni vodi")
("references" "sklicevanja")
("regular" "regularen")
("release" "release")
("reload" "ponovno naloi")
("remark" "opomba")
("remove all output fields" "odstrani vsa izhodna polja")
("remove all output fields" "odstrani vsa vnosna polja")
("remove fields" "odstrani polja")
("remove fields" "odstrani polja")
("remove input field above" "odstrani vnosno polje nad")
("remove input field above" "odstrani vpisno polje nad")
("remove input field" "odstrani vnosno polje")
("remove input field" "odstrani vpisno polje")
("remove number" "odstrani tevilo")
("remove package" "odstrani paket")
("remove this switch" "izbrii stikalo")
("renumber this page" "ponovno otevili tekoo stran")
("repeat object" "ponovi objekt")
("replace by" "zamenjano")
("replaced one occurrence" "zamenjal enkrat")
("replaced" "zamenjav")
("replace" "zamenjaj")
("reset" "reset")
("resized" "poveano")
("resize object" "poveaj")
("results of the search for" "rezultati iskanja za")
("results of the search for" "rezultati iskanja za")
("return" "return")
("revert buffer" "povrni spis")
("revert" "povrni")
("right arrow" "puica desno")
("right arrow" "puica desno")
("right border" "desna obroba")
("right" "desno")
("right margin" "desni rob")
("right padding" "desna obloga")
("right ragged" "desna")
("right subscript" "desni indeks")
("right superscript" "desni eksponent")
("right surrounding" "desno okoli")
("rigid horizontal" "rigidno vodoravno")
("rigid" "rigidno")
("rigid space" "rigiden presledek")
("romanian" "romunsko")
("root" "koren")
("rotate backward" "zasukaj nazaj")
("rotate forward" "zasukaj naprej")
("row contains glued items" "vrstica vsebuje prilepljene predmete")
("row" "vrstica")
("runic" "rune")
("running author" "avtor")
("running title" "tekoi naslov")
("russian and Ukrainian users" "uporabniki iz Rusije in Ukrajine")
("russian" "rusko")
("sample" "primer")
("sans serif" "brez serifov")
("save as LaTeX" "shrani kot LaTeX")
("save as" "shrani kot")
("save as TeX" "shrani kot TeX")
("save buffer as" "shrani spis kot")
("save buffer" "shrani spis")
("saved" "shranjeno")
("save file" "shrani datoteko")
("save html file" "shrani datoteko HTML")
("save image" "shrani sliko")
("save latex file" "shrani datoteko LaTeX")
("save" "shrani")
("save tex file" "shrani datoteko TeX")
("save TeXmacs file" "shrani kot TeXmacs")
("save TeXmacs style file" "shrani kot TeXmacs slog")
("save this buffer" "shrani ta spis")
("save verbatim file" "shrani datoteko dobesedno")
("screen layout" "postavitev na zaslonu")
("screen margins" "robovi na zaslonu")
("screen" "zaslon")
("script above" "indeks nad")
("script below" "indeks pod")
("script" "indeks")
("script script size" "velikost indeks indeksa")
("script size" "velikost indeksa")
("scripts not accepted" "skripti so zavrnjeni")
("search" "ii")
("searching" "iem")
("search words in my documents" "ii besede v mojih dokumentih")
("search words in my documents" "ii besede v mojih dokumentih")
("search words in the documentation" "ii besede v dokumentaciji")
("search words in the documentation" "ii besede v dokumentaciji")
("search words in the source code" "ii besede v izvorni kodi")
("search words in the source code" "ii besede v izvorni kodi")
("secondary" "sekundarno")
("section" "razdelek")
("security" "varnost")
("see" "glej")
("select a document style" "izberi slog dokumenta")
("select a foreground color" "izberi barvo ospredja")
("select a language" "izberite jezik")
("selected region" "izberite regijo")
("selection" "izbira")
("selections" "izbire")
("seminar" "seminar")
("sending commands to TeXmacs" "poiljanje ukazov TeXmacs-u")
("sending commands to TeXmacs" "poiljanje ukazov TeXmacsu")
("separation between lines" "razmak med vrsticami")
("separation between paragraphs" "razmak med odstavki")
("separator" "razdelilnik")
("september" "september")
("serb" "srbsko")
("series|right" "serija|right")
("series" "serija")
("session name" "ime seje")
("session" "seja")
("sessions" "seje")
("session type" "tip seje")
("set background color of cell" "nastavi barvo ozadja celice")
("set cell mode" "nastavi reim celice")
("set extension center" "nastavi center raziritve")
("set height" "nastavi viino")
("set height of cell" "nastavi viino celice")
("set margins" "nastavi robove")
("set" "nastavi")
("set n" "nastavi n")
("set paragraph margins" "nastavi robove odstavka")
("set paragraph mode" "nastavi poravnavo odstavka")
("set printer dpi" "nastavi DPI tiskalnika")
("set printing command" "nastavi ukaz za tiskanje")
("set span" "nastavi razpetost")
("set special cell properties" "nastavi posebne lastnosti celive")
("set special table properties" "nastavi posebne lastnosti tabele")
("set text width" "nastavi irino besedila")
("settings" "nastavitve")
("setup printer" "nastavitev tiskanja")
("set width" "nastavi irino")
("set width of cell" "nastavi irino celice")
("shape" "oblika")
("shift-down" "pomakni-dol")
("shift-right" "pomakni-desno")
("short" "kratko")
("show header and footer" "pokai glavo in nogo")
("show hidden" "pokai skrito")
("show on screen" "pokai na zaslonu")
("show" "pokai")
("shrinking factor" "faktor pomanjave")
("signature" "podpis")
("size limits" "omejitve velikosti")
("size tag" "oznaka velikosti")
("size" "velikost")
("slanted" "postrani")
("sloppy" "povrno")
("slovene" "slovensko")
("small caps" "kapitelke")
("small figure" "mala slika")
("small" "majhno")
("small skip" "majhen preskok")
("small table" "mala tabela")
("source code" "izvorna koda")
("space between lines" "presledek med vrsticami")
("space between paragraphs" "presledek med odstavki")
("space" "presledek")
("spacing" "razmak")
("spanish" "pansko")
("special cell properties" "posebne lastnosti celice")
("special" "posebno")
("special table properties" "posebne lastnosti tabele")
("specific" "specifino")
("spell checking complete" "kontrola pravopisa konana")
("spelling error" "pravopisna napaka")
("spelling errors have been corrected" "pravopisne napake popravljene")
("spell" "pravopis")
("split" "razdeli")
("split session" "predeli sejo")
("split session" "razdeli sejo")
("square root" "kvadratni koren")
("standard environment variables" "standardne spremenljivke okolja")
("standard TeXmacs styles" "standardni TeXmacs slogi")
("start a new chapter" "zani novo poglavje")
("start a new section" "zani nov razdelek")
("start an interactive session" "poeni interaktivno sejo")
("start" "zaetek")
("status bar" "statusna vrstica")
("stretchable horizontal" "vodoravno raztegljivo")
("stretchable" "raztegljivo")
("stretchable vertical" "navpino raztegljivo")
("stroke" "prertano")
("strokes" "prertaji")
("strong" "mono")
("structural" "strukturno")
("style" "slog")
("styles" "slogi")
("subparagraph" "pododstavek")
("sub" "pod-")
("subscript" "indeks")
("subsection" "podrazdelek")
("subsub" "podpod-")
("subsubsection" "podpodrazdelek")
("subtable" "podtabela")
("subtitle" "podnaslov")
("summary of the principal TeXmacs tags" "povzetek glavnih TeXmacs znak")
("summary" "povzetek")
("superposed" "superponirano")
("superpose" "superpozicija")
("superscript" "eksponent")
("swedish" "vedsko")
("switching and folding" "preklapljanje in prepogibanje")
("switch" "stikalo")
("switch to first" "preklopi na prvega")
("switch to formula style" "preklopi na formule")
("switch to last" "preklopi na zadnjega")
("switch to next" "preklopi na naslednjega")
("switch to previous" "preklopi na prejnjega")
("symbol" "simbol")
("system environment variables" "spremenljivke sistemskega okolja")
("table command" "ukaz za tabele")
("table of contents" "kazalo")
("tables" "tabele")
("table" "tabela")
("tab" "tabulator")
("tabular material" "tabularni material")
("tabular" "tabular")
("ternary" "terciarno")
("test" "test")
("teXmacs as an interface" "TeXmacs kot vmesnik")
("teXmacs fonts" "pisave v TeXmacsu")
("teXmacs notice" "TeXmacs opomba")
("teXmacs plugins" "TeXmacs vstavki")
("teXmacs plugins" "TeXmacs vstavki")
("teXmacs primitives" "TeXmacs primitivi")
("teXmacs style files" "TeXmacs slogovne datoteke")
("text" "besedilo")
("tex" "TeX")
("TeX" "TeX")
("text font" "pisava besedila")
("text height correction" "popravek viine besedila")
("texts" "besedila")
("text width" "irina besedila")
("thai" "tajsko")
("th century bc" ". stoletje")
("the application did not send its usual startup banner" "aplikacija ni poslala obiajnega startnega sporoila")
("the application does not reply" "aplikacija se ne odziva")
("the application is already running" "aplikacija e tee")
("the boxes produced by the typesetter" "katle, ki jih naredi stavec")
("the graphical user interface" "grafini uporabniki vmesnik")
("the leaves of TeXmacs trees" "listi TeXmacs dreves")
("the mycas example" "primer z Mycas")
("theorem" "izrek")
("the primitive TeXmacs constructs" "primitivni TeXmacs konstrukti")
("there are unsaved files" "nekatere datoteke niso shranjene")
("the standard TeXmacs styles" "standardni TeXmacs slogi")
("the TeXmacs authors" "TeXmacs avtorji")
("the TeXmacs format" "oblika TeXmacs datotek")
("the buffer has not been saved" "spis ni shranjen")
("this document has been produced using" "ta dokument je bil narejen z")
("this line" "ta vrstica")
("this page" "ta stran")
("th root" "-ti koren")
("tilda" "tilda")
("tilde" "tilda")
("times" "times")
("tiny" "drobno")
("title" "naslov")
("today" "danes")
("tools" "orodja")
("top border" "zgornja obroba")
("top level" "zgornji nivo")
("top margin" "zgornji rob")
("top padding" "zgornja obloga")
("top" "vrh")
("to the left" "na levo")
("to the right" "na desno")
("translate" "pretolmai")
("tree" "drevo")
("tuple" "n-terka")
("turkish" "turko")
("tutorial" "lekcija")
("type a latex command followed by" "napiite LaTeX ukaz, ki mu sledi")
("type body" "napii telo")
("type denominator" "napii imenovalec")
("type numerator" "napii tevec")
("type script" "napii skript")
("typesetted boxes" "postavljene katle")
("type" "tip")
("typewriter" "pisalni stroj")
("typewriter small caps" "pisalni stroj male kapitelke")
("typing a simple text" "pisanje preprostega besedila")
("typing simple texts" "pisanje preprostih besedil")
("ugaritic" "ugaritic")
("ukrainian" "ukrajinsko")
("underbrace" "podklepaj")
("underbrace" "podklepaj")
("underline" "podrtano")
("undo last changes" "razveljavi zadnje spremembe")
("undo" "razveljavi")
("unevaluated argument" "neovrednoten argument")
("unevaluated value" "neovrednotena vrednost")
("unfold" "zravnaj")
("update from web" "posodobi s spleta")
("update image links" "posodobi povezave na slike")
("update" "posodobi")
("up" "gor")
("upper border" "gornja obroba")
("use a black color" "uporabi rno barvo")
("use a blue color" "uporabi modro barvo")
("use a bold font" "uporabi krepko pisavo")
("use a brown color" "uporabi rjavo barvo")
("use a calligraphic font" "uporabi kaligrafsko pisavo")
("use a green color" "uporabi zeleno barvo")
("use a grey color" "uporabi sivo barvo")
("use a magenta color" "uporabi magenta barvo")
("use a orange color" "uporabi oranno barvo")
("use a pink color" "uporabi ronato barvo")
("use a red color" "uporabi rdeo barvo")
("use a sans serif font" "uporabi pisavo brez serifov")
("use a typewriter font" "uporabi pisavo pisalnega stroja")
("use a white color" "uporabi belo barvo")
("use a yellow color" "uporabi rumeno barvo")
("use blackboard bold font" "uporabi pisavo blackboard bold")
("use bold font series" "uporabi krepko serijo pisave")
("use calligraphical font" "uporabi kaligrafsko pisavo")
("use footnote font size" "uporabi velikost pisave za opombe pod rto")
("use fraktur font" "uporabi pisavo fraktur")
("use huge font size" "uporabi ogromno pisavo")
("use italic font shape" "uporabi kurzivno pisavo")
("use large font size" "uporabi veliko pisavo")
("use left hand column as border" "uporabi levi stolpec kot obrobo")
("use medium font series" "uporabni srednjekrepko serijo pisave")
("use normal font size" "uporabi normalno velikost")
("use package" "uporabi paket")
("use paragraph width" "uporabi irino odstavka")
("use really huge font size" "uporabi zares ogromno velikost pisave")
("use right font shape" "uporabi desno obliko pisave")
("use right hand column as border" "uporabi desni stolpec kot obrobo")
("user manual" "uporabniki prironik")
("use roman font family" "uporabi pisavo roman")
("use row above as border" "uporabi gornjo vrstico kot obrobo")
("use row below as border" "uporabi spodnjo vrsticko kot obrobo")
("user provided icons" "uporabnikove ikone")
("users of Cyrillic languages" "uporabniki jezikov v cirilici")
("users of Cyrillic languages" "uporabniki jezikov v Cirilici")
("use sans serif font family" "uporabi druino pisave brez serifov")
("use script font size" "uporabi velikost pisave za indekse")
("use slanted font shape" "uporabi postrani obliko pisave")
("use small capitals" "uporabi kapitelke")
("use small-caps font shape" "uporabi male kapitelke")
("use small font size" "uporabi malo pisavo")
("use TeXmacs" "uporabljajte TeXmacs")
("use the blackboard bold font" "uporabi obliko blackboard bold")
("use the fraktur font" "uporabi pisavo fraktur")
("use tiny font font size" "uporabi drobno pisavo")
("use typewriter font family" "uporabi pisavo pisalnega stroja")
("use very large font size" "uporabi zelo veliko pisavo")
("value" "vrednost")
("variable" "spremenljivka")
("variant" "varianta")
("vector" "vektor")
("verbatim" "dobesedno")
("verse" "verz")
("vertical after" "navpino za")
("vertical before" "navpino pred")
("vertical cell alignment" "navpina poravnava celice")
("vertically align cell to the base" "navpino poravnaj celico na bazo")
("vertically center the cell" "navpino centriraj celico")
("vertical" "navpino")
("vertical part" "navpini del")
("vertical position" "navpina pozicija")
("vertical space" "navpini presledek")
("vertical table alignment" "navpina poravnava tabele")
("very large" "zelo veliko")
("very small" "zelo majhno")
("vietnamese" "vietnamsko")
("view" "pogled")
("visible" "vidno")
("warning" "opozorilo")
("web" "splet")
("welcome" "dobrodoli")
("welcome to GNU TeXmacs" "Dobrodoli v GNU TeXmacs")
("what is new" "kaj je novega")
("when finished" "po zakljuku")
("while" "while")
("white" "bela")
("wide accent" "iroki akcent")
("wide bar" "iroka rta")
("width" "irina")
("width is exactly the specified width" "irina je natanko doloena irina")
("width is maximum of specified width and box width" "irina je maksimum doloene irine in irine katle")
("width is minimum of specified width and box width" "irina je minimum doloene irine in irine katle")
("width magnification" "poveava irine")
("window height" "viina okna")
("window" "okno")
("windows key" "tipka windows")
("window width" "irina okna")
("with" "with")
("write a name" "pii ime")
("write bold mathematics" "pii krepko matematiko")
("write bold text" "pii krepko besedilo")
("write italic text" "pii kurzivno besedilo")
("write sample text" "pii primer besedila")
("write strong text" "pii mono besedilo")
("write typewriter text" "pii besedilo na pisalni stroj")
("write verbatim text" "pii besedilo dobesedno")
("writing data converters" "tvorba pretvornikov podatkov")
("writing your own style files" "tvorba lastnih slogov")
("written with TeXmacs" "napisano z TeXmacs")
("xml" "XML")
("yellow" "rumena")
("you can also obtain" "lahko tudi dobite")
("your document is back in its original state" "va dokument je v svojem izvornem stanju")
("your first interface" "va prvi vmesnik")
("your language" "va jezik")
